==> nextcloud-app-mail-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Elektronska pošta",
    "Inbox" : "Dohodna pošta",
    "Sent" : "Poslano",
    "Drafts" : "Osnutki",
    "Archive" : "Arhiv",
    "Trash" : "Smeti",
    "Junk" : "Neželena pošta",
    "All" : "Vse",
    "Favorites" : "Priljubljene",
    "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
    "Delete permanently" : "Izbriši dokončno",
    "Mail Address" : "Elektronski naslov",
    "Connect" : "Poveži",
    "Subject" : "Zadeva",
    "Sending …" : "Pošiljanje ...",
    "Message sent!" : "Sporočilo je poslano!",
    "Send" : "Pošlji",
    "Upload attachment" : "Pošlji prilogo",
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "Delete" : "Izbriši",
    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje prilog.",
    "New message" : "Novo obvestilo",
    "Settings" : "Nastavitve",
    "Show all folders" : "Pokaži vse mape",
    "Collapse folders" : "Zloži mape",
    "{from}\n{subject}" : "{from}\n{subject}",
    "All inboxes" : "Vsi predali",
    "Could not load {tag}{name}{endtag}" : "Ne morem naložiti {tag}{name}{endtag}",
    "Error loading message" : "Napaka nalaganja sporočila",
    "Redirect" : "Preusmeri",
    "The link leads to %s" : "Povezava vodi na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
    "Continue to %s" : "Nadaljuj na %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-mail-0.15.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Elektronska pošta",
    "Inbox" : "Dohodna pošta",
    "Sent" : "Poslano",
    "Drafts" : "Osnutki",
    "Archive" : "Arhiv",
    "Trash" : "Smeti",
    "Junk" : "Neželena pošta",
    "All" : "Vse",
    "Favorites" : "Priljubljene",
    "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
    "Delete permanently" : "Izbriši dokončno",
    "Name" : "Ime",
    "Mail Address" : "Elektronski naslov",
    "Password" : "Geslo",
    "IMAP Host" : "Gostitelj IMAP",
    "None" : "Brez",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Vrata IMAP",
    "IMAP User" : "Uporabnik IMAP",
    "IMAP Password" : "Geslo IMAP",
    "SMTP Host" : "Gostitelj SMTP",
    "SMTP Port" : "Vrata SMTP",
    "SMTP User" : "Uporabnik SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Connect" : "Poveži",
    "Add mail account" : "Dodaj račun elektronske pošte",
    "Subject" : "Zadeva",
    "Sending …" : "Pošiljanje ...",
    "Message sent!" : "Sporočilo je poslano!",
    "Send" : "Pošlji",
    "Upload attachment" : "Pošlji prilogo",
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "Delete" : "Izbriši",
    "Download attachment" : "Pošlji prilogo",
    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje prilog.",
    "New message" : "Novo obvestilo",
    "Settings" : "Nastavitve",
    "Show all folders" : "Pokaži vse mape",
    "Collapse folders" : "Zloži mape",
    "{from}\n{subject}" : "{from}\n{subject}",
    "All inboxes" : "Vsi predali",
    "Could not load {tag}{name}{endtag}" : "Ne morem naložiti {tag}{name}{endtag}",
    "Error loading message" : "Napaka nalaganja sporočila",
    "Redirect" : "Preusmeri",
    "The link leads to %s" : "Povezava vodi na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
    "Continue to %s" : "Nadaljuj na %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
